@@ -1029,12 +1029,13 @@ anjuta_docman_dispose (GObject *obj)
 		docman->priv->pages = NULL;
 		for (node = pages; node != NULL; node = g_list_next (node))
 		{
+			AnjutaDocmanPage* page = node->data;
+
+			g_signal_emit(docman, docman_signals[DOC_REMOVED], 0, page->doc);
+
 			/* this also tries to destroy any notebook-page-widgets, in case
-			   they're not gone already
-		 CHECKME at shutdown do we need "destroy" signals in case other plugins
-		   hold refs on any page(s) or their contents ?
-			*/
-			anjuta_docman_page_destroy ((AnjutaDocmanPage *)node->data);
+			   they're not gone already. */
+			anjuta_docman_page_destroy (page);
 		}
 		g_list_free (pages);
 	}
@@ -1127,17 +1128,12 @@ anjuta_docman_instance_init (AnjutaDocman *docman)
 static void
 anjuta_docman_class_init (AnjutaDocmanClass *klass)
 {
-	static gboolean initialized;
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 	object_class->finalize = anjuta_docman_finalize;
 	object_class->dispose = anjuta_docman_dispose;
 
-	if (!initialized)
-	{
-		initialized = TRUE;
-
 		/* Signals */
 	docman_signals [DOC_ADDED] =
 		g_signal_new ("document-added",
@@ -1169,8 +1165,6 @@ anjuta_docman_class_init (AnjutaDocmanClass *klass)
 			G_TYPE_NONE,
 			1,
 			G_TYPE_OBJECT);
-
-	}
 }
 
 GtkWidget*
