@@ -460,38 +460,6 @@ change_project_backend (ProjectManagerPlugin *plugin, AnjutaPluginDescription *b
 /* GUI callbacks
  *---------------------------------------------------------------------------*/
 
-static gboolean
-on_refresh_idle (gpointer user_data)
-{
-	ProjectManagerPlugin *plugin;
-	AnjutaStatus *status;
-	GError *err = NULL;
-
-	plugin = ANJUTA_PLUGIN_PROJECT_MANAGER (user_data);
-
-	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell, NULL);
-	anjuta_status_push (status, _("Refreshing symbol tree…"));
-	anjuta_status_busy_push (status);
-
-	anjuta_pm_project_refresh (plugin->project, &err);
-	if (err)
-	{
-		anjuta_util_dialog_error (get_plugin_parent_window (plugin),
-								  _("Failed to refresh project: %s"),
-								  err->message);
-		g_error_free (err);
-	}
-	anjuta_status_busy_pop (status);
-	anjuta_status_pop (status);
-	return FALSE;
-}
-
-static void
-on_refresh (GtkAction *action, ProjectManagerPlugin *plugin)
-{
-	g_idle_add (on_refresh_idle, plugin);
-}
-
 static void
 on_properties (GtkAction *action, ProjectManagerPlugin *plugin)
 {
@@ -524,23 +492,6 @@ on_new_group (GtkAction *action, ProjectManagerPlugin *plugin)
 	if (default_group != NULL) g_object_unref (default_group);
 }
 
-static void
-on_new_package (GtkAction *action, ProjectManagerPlugin *plugin)
-{
-	GtkTreeIter selected_module;
-	GList *new_module;
-	GbfTreeData *data;
-
-	update_operation_begin (plugin);
-	data = gbf_project_view_get_first_selected (plugin->view, &selected_module);
-
-	new_module = anjuta_pm_project_new_package (plugin,
-										   get_plugin_parent_window (plugin),
-										   data == NULL ? NULL : &selected_module, NULL);
-	g_list_free (new_module);
-	update_operation_end (plugin, TRUE);
-}
-
 static void
 on_add_module (GtkAction *action, ProjectManagerPlugin *plugin)
 {
@@ -622,21 +573,6 @@ on_popup_sort_shortcuts (GtkAction *action, ProjectManagerPlugin *plugin)
 	gbf_project_view_sort_shortcuts (plugin->view);
 }
 
-static void
-on_popup_new_package (GtkAction *action, ProjectManagerPlugin *plugin)
-{
-	GtkTreeIter selected_module;
-	GList *packages;
-
-	update_operation_begin (plugin);
-	gbf_project_view_get_first_selected (plugin->view, &selected_module);
-
-	packages = anjuta_pm_project_new_package (plugin,
-										   get_plugin_parent_window (plugin),
-										   &selected_module, NULL);
-	update_operation_end (plugin, TRUE);
-}
-
 static void
 on_popup_add_module (GtkAction *action, ProjectManagerPlugin *plugin)
 {
@@ -657,14 +593,14 @@ static void
 on_popup_new_group (GtkAction *action, ProjectManagerPlugin *plugin)
 {
 	GtkTreeIter selected_group;
-	AnjutaProjectNode *new_group;
 
 	update_operation_begin (plugin);
 	gbf_project_view_get_first_selected (plugin->view, &selected_group);
 
-	new_group = anjuta_pm_project_new_group (plugin,
-										   get_plugin_parent_window (plugin),
-										   &selected_group, NULL);
+	anjuta_pm_project_new_group (plugin,
+	                             get_plugin_parent_window (plugin),
+	                             &selected_group, NULL);
+	
 	update_operation_end (plugin, TRUE);
 }
 
@@ -672,15 +608,14 @@ static void
 on_popup_new_target (GtkAction *action, ProjectManagerPlugin *plugin)
 {
 	GtkTreeIter selected_group;
-	AnjutaProjectNode *new_target;
 
 	update_operation_begin (plugin);
 	gbf_project_view_get_first_selected (plugin->view, &selected_group);
 
-	new_target = anjuta_pm_project_new_target (plugin,
-											 get_plugin_parent_window (plugin),
-											 &selected_group, NULL);
-
+	anjuta_pm_project_new_target (plugin,
+	                              get_plugin_parent_window (plugin),
+	                              &selected_group, NULL);
+	
 	update_operation_end (plugin, TRUE);
 }
 
@@ -986,11 +921,6 @@ static GtkActionEntry pm_actions[] =
 		N_("Add _Library…"), NULL, N_("Add a module to a target"),
 		G_CALLBACK (on_add_module)
 	},
-	{
-		"ActionProjectNewLibrary", GTK_STOCK_ADD,
-		N_("New _Library…"), NULL, N_("Add a new package to the project"),
-		G_CALLBACK (on_new_package)
-	},
 	{
 		"ActionProjectProperties", GTK_STOCK_PROPERTIES,
 		N_("_Properties"), NULL, N_("Project properties"),
@@ -1025,11 +955,6 @@ static GtkActionEntry popup_actions[] =
 		N_("Add _Library"), NULL, N_("Add a library to a target"),
 		G_CALLBACK (on_popup_add_module)
 	},
-	{
-		"ActionPopupProjectNewLibrary", GTK_STOCK_ADD,
-		N_("New _Library"), NULL, N_("Add a new library to the project"),
-		G_CALLBACK (on_popup_new_package)
-	},
 	{
 		"ActionPopupProjectAddToProject", GTK_STOCK_ADD,
 		N_("_Add to Project"), NULL, N_("Add a source file to a target"),
@@ -1169,9 +1094,6 @@ on_treeview_selection_changed (GtkTreeSelection *sel,
 	action = anjuta_ui_get_action (ui, "ActionGroupProjectManagerPopup",
 								   "ActionPopupProjectAddLibrary");
 	g_object_set (G_OBJECT (action), "sensitive", INT_TO_GBOOLEAN (state & ANJUTA_PROJECT_CAN_ADD_MODULE), NULL);
-	action = anjuta_ui_get_action (ui, "ActionGroupProjectManagerPopup",
-								   "ActionPopupProjectNewLibrary");
-	g_object_set (G_OBJECT (action), "sensitive", INT_TO_GBOOLEAN (state & ANJUTA_PROJECT_CAN_ADD_PACKAGE), NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupProjectManagerPopup",
 								   "ActionPopupProjectRemove");
 	g_object_set (G_OBJECT (action), "sensitive", INT_TO_GBOOLEAN (state & ANJUTA_PROJECT_CAN_REMOVE), NULL);
@@ -1948,16 +1870,6 @@ get_node_from_file (const AnjutaProjectNode *root, GFile *file)
 	return node;
 }
 
-static AnjutaProjectNodeType
-get_element_type (ProjectManagerPlugin *plugin, GFile *element)
-{
-	AnjutaProjectNode *node;
-
-	node = gbf_project_view_get_node_from_file (plugin->view, ANJUTA_PROJECT_UNKNOWN,  element);
-
-	return node == NULL ? ANJUTA_PROJECT_UNKNOWN : anjuta_project_node_get_node_type (node);
-}
-
 static GList*
 iproject_manager_get_children (IAnjutaProjectManager *project_manager,
 							   GFile *parent,
@@ -2148,7 +2060,7 @@ iproject_manager_get_selected (IAnjutaProjectManager *project_manager,
 
 	node = gbf_project_view_find_selected (plugin->view,
 										   ANJUTA_PROJECT_GROUP);
-	if (node && anjuta_project_node_get_node_type (node) == GBF_TREE_NODE_GROUP)
+	if (node && anjuta_project_node_get_node_type (node) == ANJUTA_PROJECT_GROUP)
 	{
 		return g_object_ref (anjuta_project_node_get_file (node));
 	}
