@@ -55,9 +55,6 @@
 #define TOOLBAR_VISIBLE "toolbar-visible"
 #define TOOLBAR_STYLE "toolbar-style"
 
-#define ANJUTA_SESSION_SKIP_LAST "session-skip-last"
-#define ANJUTA_SESSION_SKIP_LAST_FILES "session-skip-last-files"
-
 static void anjuta_window_layout_load (AnjutaWindow *win,
 									const gchar *layout_filename,
 									const gchar *name);
@@ -220,10 +217,6 @@ anjuta_window_maximize_widget (AnjutaShell *shell,
 		if (value == NULL)
 			continue;
 
-		/* If it's the widget requesting maximization then continue */
-		if(!g_strcmp0((gchar*)key, widget_name))
-			continue;
-
 		/* Widget assertions */
 		widget = GTK_WIDGET (value);
 		if(!GTK_IS_WIDGET (widget))
@@ -234,8 +227,17 @@ anjuta_window_maximize_widget (AnjutaShell *shell,
 		if(dock_item == NULL || !GDL_IS_DOCK_ITEM (dock_item))
 			continue;
 
-		/* Hide the item */
-		gdl_dock_item_hide_item (GDL_DOCK_ITEM (dock_item));
+		if(!g_strcmp0((gchar*)key, widget_name))
+		{
+			/* If it's the widget requesting maximization then make sure the 
+			 * widget is visible*/
+			gdl_dock_item_show_item (GDL_DOCK_ITEM (dock_item));
+		}
+		else
+		{
+			/* Hide the other item */
+			gdl_dock_item_hide_item (GDL_DOCK_ITEM (dock_item));
+		}
 	}
 }
 
@@ -446,14 +448,12 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 		app = ANJUTA_APPLICATION (gtk_window_get_application (GTK_WINDOW (win)));
 		if (app != NULL)
 		{
-			if (anjuta_application_get_no_session (app) ||
-			    g_settings_get_boolean (win->settings, ANJUTA_SESSION_SKIP_LAST))
+			if (anjuta_application_get_no_session (app))
 			{
 				/* Clear session */
 				anjuta_session_clear (session);
 			}
-			else if (anjuta_application_get_no_files (app)  ||
-			    g_settings_get_boolean (win->settings, ANJUTA_SESSION_SKIP_LAST_FILES))
+			else if (anjuta_application_get_no_files (app))
 			{
 				/* Clear files from session */
 				anjuta_session_set_string_list (session, "File Loader",
@@ -718,6 +718,8 @@ anjuta_window_instance_init (AnjutaWindow *win)
 		gtk_widget_hide (win->toolbar);
 	gtk_style_context_add_class (gtk_widget_get_style_context (win->toolbar),
 	                             GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+	gtk_toolbar_set_icon_size (GTK_TOOLBAR (win->toolbar),
+	                           GTK_ICON_SIZE_MENU);
 	gtk_box_pack_start (GTK_BOX (main_box), win->toolbar, FALSE, FALSE, 0);
 	action = gtk_ui_manager_get_action (GTK_UI_MANAGER (win->ui),
 										"/MenuMain/MenuView/Toolbar");
